% Modal Interferometer Simulation Tool (MIST) - Gabriele Vajente (April 2010)
%
% Return the static fields in a dual-recycled interferometer for a unity
% input at frequency f. Compute only power recycling field
%
% [psi_rc] = dualrecycled_fields_fast(itf, f)
%
% itf = interferometer structure
% f   = field frequency
%
% psi_rc = field inside power recycling (at PR level, going away from PR)
%

function [psi_rc] = dualrecycled_fields_fast(itf, f)
    
    k = 2*pi / 1.064e-6;
    c = 299792458;
    w = 2*pi*f;
    
    % compute propagators in recycling cavities
    modes = itf.ncav.modes;
    itf.PRC = diag(sqrt(-1j) * exp(1j * k * itf.PRCL - 1j * w/c * itf.Lprc) ...
        * exp(1j * sum(modes') * itf.phig_p));
    itf.PSC = diag(sqrt(-1j) * exp(1j*itf.phi_src - 1j * w/c * itf.Lsrc) ...
        * exp(1j * sum(modes') * itf.phig_s));
    itf.PLm = sqrt(1j) * exp(1j * k * itf.MICH - 1j * w / c * itf.Schnupp/2);
    
    % compute fields
    N = size(itf.ncav.modes,1);
    U = eye(N);
    
    % Michelson operators
    itf.MSS = MSS(itf, f);
    itf.MAA = MAA(itf, f);
    itf.MSA = MSA(itf, f);
    itf.MAS = MAS(itf, f);
    
    % main fields
    SRC = inv(U - 1j*itf.PSC*itf.MAA*itf.PSC*itf.Rs);
    psi_rc = inv(U - 1j*itf.Rp*itf.PRC*itf.MSS*itf.PRC + ...
                itf.Rp*itf.PRC*itf.MAS*itf.PSC*itf.Rs* ...
                SRC * itf.PSC*itf.MSA*itf.PRC)*itf.Tp;
       
    %psi_rc = (U - 1j*itf.Rp*itf.PRC*itf.MSS*itf.PRC + ...
    %            itf.Rp*itf.PRC*itf.MAS*itf.PSC*itf.Rs* ...
    %             ((U - 1j*itf.PSC*itf.MAA*itf.PSC*itf.Rs) \ itf.PSC) *itf.MSA*itf.PRC) \itf.Tp;
      
